<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Launcher</name>
    <message>
        <location filename="../src/launcher.cpp" line="50"/>
        <source>Launcher</source>
        <translation>Indító</translation>
    </message>
</context>
<context>
    <name>LauncherGridDelegate</name>
    <message>
        <location filename="../qml/LauncherGridDelegate.qml" line="91"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../qml/LauncherGridDelegate.qml" line="96"/>
        <source>Uninstall</source>
        <translation>Eltávolítás</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="174"/>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="260"/>
        <source>Not found</source>
        <translation>Nem található</translation>
    </message>
</context>
</TS>
